#ifndef globals_h
#define globals_h

#include "RTC_EEPROM.h"

#define MAX_SENSOR_COUNT  2   // maximale Anzahl der Sensor-Paare
#define BUFFER_SIZE       200 // Buffergröße für buffer_g

#define DEBUG   0

struct SensorData {           // zur Aufnahme eines Datums von einem Sensor-Paar (3 Byte)
    signed int temp : 12;     // 12 Bit vom DS18B20 via I2C
  unsigned int ldr  : 10;     // 10 Bit vom GL5528 via analogRead()
  unsigned int bad  : 1;      // auf 1 für "temp-CRC hat nicht gepasst", auf 0 für "Daten legal"
};

struct SensorHour {           // zur Aufnahme einer vollen Stunde von Sensor-Daten
  RTCdata      timestamp;     // Start-Zeit (Minute == Start-Index in data[])
  SensorData   data[60];      // ein Messwerte-Paar pro Minute
  unsigned int checksum;      // Checksum für das EEPROM
  char EEPROM_alignment[6];   // zur Ausrichtung auf die Page-Size des AT24C32
};

extern byte ROMcode_g[MAX_SENSOR_COUNT][8];           // ROM-Codes der DS18B20 (64 Bit: 8 Bit FamilyCode=0x28, 48 Bit SerialNumber, 8 Bit CRC)

extern SensorData sensorRAM_g[MAX_SENSOR_COUNT][15];  // hier landen die Sensor-Daten einer Minute
extern byte sensorRAM_idx_g;                          // der Index dafür

extern SensorHour sensorHourRAM_g[MAX_SENSOR_COUNT];  // die Messwerte der aktuellen Stunde
extern byte sensorHourRAM_idx_g;                      // der Index für data[] in sensorHourRAM_g  (ist praktisch die aktuelle Minute)

extern signed char cycles_for_full_minute_g;          // Anzahl der Tiefschlaf-Phasen bis zum Beginn der nächsten Minute
extern signed char minutes_to_full_hour_g;            // Anzahl der Minuten bis zur nächsten Stunde

extern RTCdata power_on_timestamp_g;                  // Datum+Zeit vom Power-On

extern byte sensor_count_g;                           // die Anzahl der Sensor-Paare

extern char buffer_g[BUFFER_SIZE];                    // der Sende- und Empfangs-Buffer für den ESP8266

extern char warnings_g;                               // sammelt Warnings zur Übermittlung ans Python-Script

#endif


